Index: components/autofill/content/common/autofill_messages.h |
diff --git a/components/autofill/content/common/autofill_messages.h b/components/autofill/content/common/autofill_messages.h |
index 0fa84302fedee7c1cc7d7e4f5b3aeca4af514d47..cb9fc6a1252f615b3c57377c77dbfdbc73807f28 100644 |
--- a/components/autofill/content/common/autofill_messages.h |
+++ b/components/autofill/content/common/autofill_messages.h |
@@ -142,9 +142,15 @@ IPC_MESSAGE_ROUTED1(AutofillMsg_AcceptDataListSuggestion, |
IPC_MESSAGE_ROUTED1(AutofillMsg_GeneratedPasswordAccepted, |
base::string16 /* generated_password */) |
-// Tells the renderer that the user accepted a password autofill suggestion, |
-// and that renderer should set the username and password to the given values. |
-IPC_MESSAGE_ROUTED2(AutofillMsg_AcceptPasswordAutofillSuggestion, |
+// Tells the renderer to fill the username and password with with given |
+// values. |
+IPC_MESSAGE_ROUTED2(AutofillMsg_FillPasswordSuggestion, |
+ base::string16 /* username */, |
+ base::string16 /* password */) |
+ |
+// Tells the renderer to preview the username and password with the given |
+// values. |
+IPC_MESSAGE_ROUTED2(AutofillMsg_PreviewPasswordSuggestion, |
base::string16 /* username */, |
base::string16 /* password */) |